@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from CalendarStore import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCalCalendarStore (TestCase):
     def testConstants(self):
         self.assertEqual(CalSpanThisEvent, 0)
@@ -21,6 +26,8 @@ class TestCalCalendarStore (TestCase):
         self.assertIsInstance(CalUserUIDKey, unicode)
 
     def testMethods(self):
+        self.assertResultIsBOOL(CalCalendarStore.saveCalendar_error_)
+        self.assertResultIsBOOL(CalCalendarStore.removeCalendar_error_)
         self.assertArgIsOut(CalCalendarStore.saveCalendar_error_, 1)
         self.assertArgIsOut(CalCalendarStore.removeCalendar_error_, 1)
 
